summaryrefslogtreecommitdiffstats
path: root/libkdepim/embeddedurlpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/embeddedurlpage.cpp')
-rw-r--r--libkdepim/embeddedurlpage.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdepim/embeddedurlpage.cpp b/libkdepim/embeddedurlpage.cpp
index 12b25dedb..e73911f00 100644
--- a/libkdepim/embeddedurlpage.cpp
+++ b/libkdepim/embeddedurlpage.cpp
@@ -33,8 +33,8 @@
using namespace KPIM;
EmbeddedURLPage::EmbeddedURLPage( const TQString &url, const TQString &mimetype,
- TQWidget *parent, const char *name )
- : TQWidget( parent, name ), mUri(url), mMimeType( mimetype ), mPart( 0 )
+ TQWidget *tqparent, const char *name )
+ : TQWidget( tqparent, name ), mUri(url), mMimeType( mimetype ), mPart( 0 )
{
initGUI( url, mimetype );
}
@@ -54,8 +54,8 @@ void EmbeddedURLPage::loadContents()
TQString mimetype = mMimeType;
if ( mimetype == "auto" )
mimetype == KMimeType::findByURL( mUri )->name();
- // "this" is both the parent widget and the parent object
- mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, this, 0, this, 0 );
+ // "this" is both the tqparent widget and the tqparent object
+ mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), this, 0, this, 0 );
if ( mPart ) {
mPart->openURL( mUri );
mPart->widget()->show();